@@ -5,6 +5,7 @@ use Datahub::Factory::Sane;
 use Catmandu;
 use Moose::Role;
 use namespace::clean;
+use Try::Tiny;
 
 has importer => (is  => 'lazy');
 has logger   => (is => 'lazy');
@@ -16,6 +17,23 @@ sub _build_logger {
     return Log::Log4perl->get_logger('datahub');
 }
 
+# Do the same for exporter
+sub each {
+    my ($self, $callback) = @_;
+    try {
+        return $self->importer->each($callback);
+    } catch {
+        my $error_msg;
+        if ($_->can('message')) {
+            $error_msg = sprintf('Fatal error while executing import: %s', $_->message);
+        } else {
+            $error_msg = sprintf('Fatal error while executing import: %s', $_);
+        }
+        $self->logger->fatal($error_msg);
+        exit 1;
+    };
+}
+
 
 1;
 __END__
